@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-04-15'; # DATE
+our $DATE = '2023-07-09'; # DATE
 our $DIST = 'Perinci-Examples'; # DIST
-our $VERSION = '0.823'; # VERSION
+our $VERSION = '0.824'; # VERSION
 
 our %SPEC;
 
@@ -102,7 +102,7 @@ Perinci::Examples::ArgsAs - Demonstrate various values of `args_as` function met
 
 =head1 VERSION
 
-This document describes version 0.823 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2022-04-15.
+This document describes version 0.824 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2023-07-09.
 
 =head1 DESCRIPTION
 
@@ -152,10 +152,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$arg1>* => I<str>
 
+(No description)
+
 =item * B<$arg2>* => I<int>
 
+(No description)
+
 =item * B<$arg3> => I<float>
 
+(No description)
+
 
 =back
 
@@ -202,10 +208,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$arg1>* => I<str>
 
+(No description)
+
 =item * B<$arg2>* => I<int>
 
+(No description)
+
 =item * B<$arg3> => I<float>
 
+(No description)
+
 
 =back
 
@@ -256,10 +268,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg1>* => I<str>
 
+(No description)
+
 =item * B<arg2>* => I<int>
 
+(No description)
+
 =item * B<arg3> => I<float>
 
+(No description)
+
 
 =back
 
@@ -310,10 +328,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg1>* => I<str>
 
+(No description)
+
 =item * B<arg2>* => I<int>
 
+(No description)
+
 =item * B<arg3> => I<float>
 
+(No description)
+
 
 =back
 
@@ -353,13 +377,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
