@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-04-15'; # DATE
+our $DATE = '2023-07-09'; # DATE
 our $DIST = 'Perinci-Examples'; # DIST
-our $VERSION = '0.823'; # VERSION
+our $VERSION = '0.824'; # VERSION
 
 our %SPEC;
 
@@ -324,7 +324,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.823 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2022-04-15.
+This document describes version 0.824 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2023-07-09.
 
 =head1 DESCRIPTION
 
@@ -383,11 +383,11 @@ Result:
    {
      logs => [
                {
-                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.34.0/lib/site_perl/5.34.0/Perinci/Access/Schemeless.pm",
+                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.38.0/lib/site_perl/5.38.0/Perinci/Access/Schemeless.pm",
                  func    => "Perinci::Access::Schemeless::action_call",
-                 line    => 501,
+                 line    => 500,
                  package => "Perinci::Access::Schemeless",
-                 time    => 1650005527,
+                 time    => 1688898612,
                  type    => "create",
                },
              ],
@@ -513,6 +513,8 @@ instead of the less informative:
 
 =item * B<pass> => I<str>
 
+(No description)
+
 =item * B<str1>* => I<str>
 
 A required option as well as positional argument.
@@ -567,6 +569,8 @@ Another bool option.
 
 =item * B<flag1> => I<bool>
 
+(No description)
+
 =item * B<str1>* => I<str>
 
 A required option as well as positional argument.
@@ -616,13 +620,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
