@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-04-15'; # DATE
+our $DATE = '2023-07-09'; # DATE
 our $DIST = 'Perinci-Examples'; # DIST
-our $VERSION = '0.823'; # VERSION
+our $VERSION = '0.824'; # VERSION
 
 our %SPEC;
 
@@ -227,7 +227,7 @@ Perinci::Examples::CmdLineSrc - Examples for using cmdline_src function property
 
 =head1 VERSION
 
-This document describes version 0.823 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2022-04-15.
+This document describes version 0.824 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2023-07-09.
 
 =head1 FUNCTIONS
 
@@ -251,6 +251,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<data> => I<buf> (default: "\0\0\0")
 
+(No description)
+
 
 =back
 
@@ -283,8 +285,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1>* => I<str>
 
+(No description)
+
 =item * B<a2> => I<array>
 
+(No description)
+
 
 =back
 
@@ -317,6 +323,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<int>
 
+(No description)
+
 
 =back
 
@@ -349,8 +357,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<str>
 
+(No description)
+
 =item * B<a2> => I<str>
 
+(No description)
+
 
 =back
 
@@ -385,10 +397,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1>* => I<str>
 
+(No description)
+
 =item * B<a2>* => I<str>
 
+(No description)
+
 =item * B<a3>* => I<str>
 
+(No description)
+
 
 =back
 
@@ -421,6 +439,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<array>
 
+(No description)
+
 
 =back
 
@@ -453,8 +473,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1>* => I<str>
 
+(No description)
+
 =item * B<a2>* => I<str>
 
+(No description)
+
 
 =back
 
@@ -487,6 +511,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<array[str]>
 
+(No description)
+
 
 =back
 
@@ -519,6 +545,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<array>
 
+(No description)
+
 
 =back
 
@@ -551,6 +579,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<str>
 
+(No description)
+
 
 =back
 
@@ -583,6 +613,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<array>
 
+(No description)
+
 
 =back
 
@@ -615,6 +647,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<str>
 
+(No description)
+
 
 =back
 
@@ -647,6 +681,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<str>
 
+(No description)
+
 
 =back
 
@@ -679,6 +715,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a1> => I<str>
 
+(No description)
+
 
 =back
 
@@ -718,13 +756,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
