@@ -7,9 +7,9 @@ use warnings;
 use Fcntl qw(:DEFAULT);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-04-15'; # DATE
+our $DATE = '2023-07-09'; # DATE
 our $DIST = 'Perinci-Examples'; # DIST
-our $VERSION = '0.823'; # VERSION
+our $VERSION = '0.824'; # VERSION
 
 our %SPEC;
 
@@ -58,7 +58,7 @@ sub read_file {
 
     open my($fh), "<", $path or return [500, "Can't open '$path': $!"];
 
-    [200, "OK", sub { ~~<$fh> }, {stream=>1}];
+    [200, "OK", sub { scalar <$fh> }, {stream=>1}];
 }
 
 $SPEC{write_file} = {
@@ -164,7 +164,7 @@ Perinci::Examples::FileStream - Examples for reading/writing files (using stream
 
 =head1 VERSION
 
-This document describes version 0.823 of Perinci::Examples::FileStream (from Perl distribution Perinci-Examples), released on 2022-04-15.
+This document describes version 0.824 of Perinci::Examples::FileStream (from Perl distribution Perinci-Examples), released on 2023-07-09.
 
 =head1 DESCRIPTION
 
@@ -198,8 +198,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<content>* => I<buf>
 
+(No description)
+
 =item * B<path>* => I<str>
 
+(No description)
+
 
 =back
 
@@ -240,6 +244,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<path>* => I<str>
 
+(No description)
+
 
 =back
 
@@ -288,8 +294,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<content>* => I<buf>
 
+(No description)
+
 =item * B<path>* => I<str>
 
+(No description)
+
 
 =back
 
@@ -329,13 +339,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
