@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-04-15'; # DATE
+our $DATE = '2023-07-09'; # DATE
 our $DIST = 'Perinci-Examples'; # DIST
-our $VERSION = '0.823'; # VERSION
+our $VERSION = '0.824'; # VERSION
 
 our %SPEC;
 
@@ -78,7 +78,7 @@ Perinci::Examples::ResultNaked - Demonstrate `result_naked` property
 
 =head1 VERSION
 
-This document describes version 0.823 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2022-04-15.
+This document describes version 0.824 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2023-07-09.
 
 =head1 DESCRIPTION
 
@@ -114,7 +114,7 @@ Examples:
 
 =item * With the optional arg3:
 
- result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg3", 0.5, "arg1", "def", "arg2", 20]
+ result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg3", 0.5, "arg2", 20, "arg1", "def"]
 
 =back
 
@@ -126,10 +126,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg1>* => I<str>
 
+(No description)
+
 =item * B<arg2>* => I<int>
 
+(No description)
+
 =item * B<arg3> => I<float>
 
+(No description)
+
 
 =back
 
@@ -159,7 +165,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg2", 20, "arg3", 0.5, "arg1", "def"], {}]
+ [200, "OK", ["arg1", "def", "arg2", 20, "arg3", 0.5], {}]
 
 =back
 
@@ -171,10 +177,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg1>* => I<str>
 
+(No description)
+
 =item * B<arg2>* => I<int>
 
+(No description)
+
 =item * B<arg3> => I<float>
 
+(No description)
+
 
 =back
 
@@ -214,13 +226,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
