@@ -2,9 +2,9 @@
 package Perinci::Examples::Tiny::Args;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-04-15'; # DATE
+our $DATE = '2023-07-09'; # DATE
 our $DIST = 'Perinci-Examples'; # DIST
-our $VERSION = '0.823'; # VERSION
+our $VERSION = '0.824'; # VERSION
 
 our %SPEC;
 
@@ -134,7 +134,7 @@ Perinci::Examples::Tiny::Args - Tests related to function arguments
 
 =head1 VERSION
 
-This document describes version 0.823 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2022-04-15.
+This document describes version 0.824 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2023-07-09.
 
 =head1 DESCRIPTION
 
@@ -161,6 +161,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg> => I<any>
 
+(No description)
+
 
 =back
 
@@ -193,8 +195,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<date>* => I<date>
 
+(No description)
+
 =item * B<duration>* => I<duration>
 
+(No description)
+
 
 =back
 
@@ -227,6 +233,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<date>* => I<date>
 
+(No description)
+
 
 =back
 
@@ -259,8 +267,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<a.number>* => I<int>
 
+(No description)
+
 =item * B<another.number>* => I<float>
 
+(No description)
+
 
 =back
 
@@ -293,6 +305,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<duration>* => I<duration>
 
+(No description)
+
 
 =back
 
@@ -332,13 +346,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
