@@ -2,9 +2,9 @@
 package Perinci::Examples::Version;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-04-15'; # DATE
+our $DATE = '2023-07-09'; # DATE
 our $DIST = 'Perinci-Examples'; # DIST
-our $VERSION = '0.823'; # VERSION
+our $VERSION = '0.824'; # VERSION
 
 our %SPEC;
 
@@ -29,7 +29,7 @@ Perinci::Examples::Version - Package that contains entity_v in its Rinci package
 
 =head1 VERSION
 
-This document describes version 0.823 of Perinci::Examples::Version (from Perl distribution Perinci-Examples), released on 2022-04-15.
+This document describes version 0.824 of Perinci::Examples::Version (from Perl distribution Perinci-Examples), released on 2023-07-09.
 
 =head1 DESCRIPTION
 
@@ -58,13 +58,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
